sparky-polkit for Debian
-----------------------

<This file describes information about the source package, see Debian policy
manual section 4.14. You WILL either need to modify or delete this file.>



 -- pavroo <pavroo@onet.eu>  Mon, 22 Dec 2025 16:02:33 +0000
